@@ -16,10 +16,12 @@
 # along with pytilities.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+__docformat__ = 'reStructuredText'
+
 from pytilities.testing import test_suite_from_package
 from pytilities import testing
 
 test_suite = test_suite_from_package(__file__, __name__)
 
 def run():
-    testing.run(test_suite)
+    return testing.run(test_suite)
